@@ -53,11 +53,6 @@ sub port {
 sub start {
     my OPCUA::Open62541::Test::Server $self = shift;
 
-    ok($self->{port} ||= empty_port(), "server: empty port");
-    note("going to configure server on port $self->{port}");
-    is($self->{config}->setMinimal($self->{port}, ""), STATUSCODE_GOOD,
-	"server: set minimal config");
-
     ok($self->{logger} = $self->{config}->getLogger(), "server: get logger");
     ok($self->{log} = OPCUA::Open62541::Test::Logger->new(
 	logger => $self->{logger},
@@ -65,6 +60,23 @@ sub start {
     ), "server: test logger");
     ok($self->{log}->file($self->{logfile}), "server: log file");
 
+    ok($self->{port} ||= empty_port(), "server: empty port");
+    note("going to configure server on port $self->{port}");
+
+    if ($self->{certificate} and $self->{privateKey}) {
+	is(
+	    $self->{config}->setDefaultWithSecurityPolicies(
+		$self->{port}, $self->{certificate}, $self->{privateKey},
+		$self->{trustList}, $self->{issuerList}, $self->{revocationList},
+	    ),
+	    STATUSCODE_GOOD,
+	    "server: set security config"
+	);
+    } else {
+	is($self->{config}->setMinimal($self->{port}, ""), STATUSCODE_GOOD,
+	    "server: set minimal config");
+    }
+
     return $self;
 }
 
@@ -492,6 +504,29 @@ Array of CODE refs with predefined actions that can be executed during runtime.
 The CODE refs will get called with the Server object of the child process as an
 argument.
 
+=item $args{certificate}
+
+Certificate in DER format for signing and encryption.
+If I<certificate> and I<privateKey> are set, the server config will be
+configured with the relevant security policies.
+
+=item $args{privateKey}
+
+Private key in DER format that has to match the certificate.
+
+=item $args{trustList}
+
+Array reference with a list of trusted certificates in PEM or DER format.
+
+=item $args{issuerList}
+
+Array reference with a list of additional trusted certificates in PEM or DER format.
+
+=item $args{revocationList}
+
+Array reference with a list of certificate revocation lists (CRL) in PEM or DER
+format.
+
 =item $args{logfile}
 
 Logs to the specified file instead of "server.log" in the current
@@ -582,10 +617,13 @@ OPCUA::Open62541::Test::Logger
 =head1 AUTHORS
 
 Alexander Bluhm E<lt>bluhm@genua.deE<gt>,
+Anton Borowka
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2020 Alexander Bluhm
+Copyright (c) 2020-2023 Alexander Bluhm
+
+Copyright (c) 2020-2023 Anton Borowka
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
